@@ -1,6 +1,6 @@
 "cell" <-
-structure(list(V1 = c(1.175, 1.175, 2.35, 2.35, 4.7, 4.7, 4.7, 
-7.05, 7.05, 9.4, 9.4, 9.4, 14.1, 14.1), V2 = c(-0.821, -0.598, 
+structure(list(dose = c(1.175, 1.175, 2.35, 2.35, 4.7, 4.7, 4.7, 
+7.05, 7.05, 9.4, 9.4, 9.4, 14.1, 14.1), log.surv = c(-0.821, -0.598, 
 -1.833, -2.04, -3.219, -3.932, -2.794, -5.298, -5.745, -6.812, 
 -8.805, -8.568, -4.962, -9.721)), class = "data.frame", row.names = c("1", 
 "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
